#
# spec file for package snes9x
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           snes9x
Version:        1.54.1
Release:        1.1
Summary:        Portable, freeware Super Nintendo Entertainment System (TM) emulator
License:        Other License (s) , see package
Group:          System/Emulators/Other
URL:            http://www.snes9x.com/
Source:         https://github.com/snes9xgit/snes9x/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch30:        snes9x-1.53-unix-cflags.patch
BuildRequires:  alsa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  libdrm-devel
BuildRequires:  libpng-devel
BuildRequires:  libxml2-devel
BuildRequires:  nasm
BuildRequires:  pulseaudio-devel
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-devel
BuildRequires:  xorg-x11-libXv
BuildRequires:  zlib-devel
%if 0%{?suse_version} == 1110
BuildRequires:  SDL-devel
%else
BuildRequires:  libSDL-devel
%endif

%description
Snes9x is a portable, freeware Super Nintendo Entertainment System
(SNES) emulator. It basically allows you to play most games designed
for the SNES and Super Famicom Nintendo game systems on your PC.

Additionally, this package contains snes9x-gtk, a graphical front-end
making the use of snes9x a lot less difficult.

%prep
%setup -q
%patch30
# On openSUSE, joysticks appear under /dev/input:
perl -pi -e 's,/dev/js,/dev/input/js,g;' unix/unix.cpp

%build
pushd unix
  %configure --enable-netplay \
      CFLAGS="%{optflags}" CXXFLAGS="%{optflags}"
  make %{?_smp_mflags}
popd

pushd gtk
  ./autogen.sh
  %configure --prefix=%{_prefix} \
    --with-opengl \
    --with-oss --with-alsa --with-pulseaudio \
    CFLAGS="%{optflags}" CXXFLAGS="%{optflags}"
  make %{?_smp_mflags}
popd

%install
DOCDIR=%{_docdir}/snes9x
install -d %{buildroot}%{_bindir}
install unix/snes9x %{buildroot}%{_bindir}
install gtk/snes9x-gtk %{buildroot}%{_bindir}
install -d $RPM_BUILD_ROOT${DOCDIR}
install -m644 docs/changes.txt docs/control-inputs.txt docs/controls.txt docs/gpl-2.0.txt docs/lgpl-2.1.txt docs/porting.html docs/portsofsnes9x.txt docs/snapshots.txt docs/snes9x.conf.default docs/snes9x-license.txt $RPM_BUILD_ROOT${DOCDIR}
install -m644 unix/docs/readme_unix.html  $RPM_BUILD_ROOT${DOCDIR}
install -m644 gtk/doc/LICENSE gtk/doc/lgpl.txt $RPM_BUILD_ROOT${DOCDIR}
#Desktop icon
mkdir -p %{buildroot}%{_datadir}/pixmaps
mkdir -p %{buildroot}%{_datadir}/applications
install -m 644 gtk/data/snes9x_32x32.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
install -m 644 gtk/data/snes9x.desktop %{buildroot}%{_datadir}/applications/
%suse_update_desktop_file -r -G %{name} %{name} System Emulator

%files
%{_bindir}/%{name}*
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/applications/%{name}.desktop
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/*

%changelog
* Fri Nov 10 2017 aavindraa@gmail.com
- update to 1.54.1
  * Properly use --std=c++11 when compiling xBRZ
- includes changes from 1.54
  * Changed the S-SMP core module to one written by byuu. While this
    increases accuracy, uses fewer speed hacks, it also regresses
    a few speed-hack games.
  * Improved IRQ emulation in several cases
  * Added rewind support
  * Included libretro port
  * Added bps soft-patching support
  * Fixed MMC bank register bit 7, restored 64mbit ExLoRom map
  * Added xBRZ filter
  * Fixed several issues with GTK+3
  * Added extra aspect ratio options
  * Added option to mute sound when using turbo mode
  * Fixed expose handling to reduce overdraw and improve
    performance.
  * Updated and universalized Spanish translation
  * Unix: Added Xv support and fixed several bugs
- Cleanup with spec-cleaner
- Drop snes9x-1.53-gtk-open.patch
  * upstreamed in 6d74746342a73cf65db215f4fdecdfb0cae66792
- Drop snes9x-1.53-unix-js.patch
  * file is being patched correctly during setup anyway
* Thu Jan  8 2015 stefan@fam-elser.de
- Added desktop file to spec file
- Fixed build for SLES11
* Sun Feb 16 2014 subchaser1@gmail.com
- snes9x version update to 1.53
- snes9x-gtk graphical front-end added
- snes9x-1.53-gtk-open.patch: fix crashing on file open
- snes9x-1.53-unix-js.patch: fix paths to joystick inputs
- snes9x-1.53-unix-cflags.patch: fix CFLAGS handling in configure
- The changes since 1.5 are to numerous to list here, please read
  the file /usr/share/doc/packages/snes9x/changes.txt for
  a complete list
* Thu Jul 15 2010 uli@suse.de
- fixed to build in Factory
- ditched frontend, doesn't belong here (and doesn't build either)
* Fri Jun 13 2008 uli@suse.de
- fixed to build with new toolchain
* Sat Nov 11 2006 aj@suse.de
- Fix permissions of documentation files.
* Sun Jul 16 2006 hmacht@suse.de
- sens9x version update to 1.5
- added patch to avoid C/C++ linkage intermixture
  Upstream changelog:
  Snes9x 1.5
- Pseudo-hires rendering flush, Old 2xsai endian fix (anomie)
- Added 'oops' auto-snapshot support (anomie)
- Fixed usage messages (Unix) (anomie)
- Old split-ROM-in-zip bugfix (anomie)
- ./configure fix for detecting libpng (anomie)
- Fix "no PNG support" error message (anomie)
- Anomie's control remapping patch (anomie)
- Support for IPS patches in the zip file (anomie)
- OBC1 savestate fix (Overload)
- Fix turbo frameskip, X11 keyboard auto-repeat, VRAM reads
  (anomie)
- Add some missing ifdefs (UNZIP_SUPPORT and ZLIB),
  from AaronOneal (anomie)
- Config file for Unix/X11 and Unix/SVGA (anomie)
- CPU instruction fixes (mostly emulation mode & timing) (anomie)
- Mode 7 fixes (anomie)
- Rewrote the renderer. Enjoy! (anomie)
- Correct-ish memmap boundary testing. (anomie)
- Add support for saner directory structures under Unix (anomie)
- Unix: Fixed detection of newer libpng (spotted by vapier)
  (PBortas)
- Added 4-point gaussian interpolation and proper envelopes
  many thanks to Brad Martin and TRAC. (zones)
- Fixed several sound problems. (zones)
- Fixed the memory access problem in C++ Super FX core. (zones)
- Speed adjustment of C++ Super FX emulation. (zones)
- Various timing fixes: NMI, IRQ, WRAM refresh,
  cycles per line, HBlank start, etc.
  Many thanks to byuu for much information. (zones)
- Removed some game specific hacks. (zones)
- Added partial Satellaview (BS) emulation. (Dreamer Nom, zones)
- Added the Katakana font for onscreen messages. (107)
- Updated JMA to v1 (Nach)
- Unix: Fixed JMA options in config (Nach)
- Unix: Removed --with(out)-asmcpu option in config
  because the i386 assembler CPU core is out of date. (zones)
- Unix: Changed the default settings in config. (zones)
- Updated porting.html (porting.txt) in sync with 1.5. (zones)
- Fixed buffer over/under flow due to incorrect logical
  operator in S-RTC code (byuu)
- Fixed HDMA flags bug. (byuu, anomie)
- Fixed bugs causing crashing in Unix. (Nach)
- Ported Snes9x to AMD64. (John Weidman, Nach, zones)
- Completed DSP-1 code. (Andreas Naive, Overload, Nach)
- Updated DSP-3 code. (Nach, z80 gaiden)
- Updated DSP-4 code. (Dreamer Nom, Nach, z80 gaiden)
- Overhauled BS detection. (Nach)
- Improved Unix portability. (Nach, zones)
- Fixed infiniti loop and invalid read bug in
  C++ C4 core. (Nach)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 hmacht@suse.de
- fix build errors
* Tue Aug  2 2005 ro@suse.de
- use gtk2-devel-packages in nfb
* Wed May 18 2005 hmacht@suse.de
- added readme.suse
* Fri May  6 2005 yxu@suse.de
- fixed for GCC4
* Mon May  2 2005 ro@suse.de
- fix build with gcc-4
* Tue Apr  5 2005 hmacht@suse.de
- upgrade to version 1.43
- removed zlib patch
* Thu May  6 2004 hmacht@suse.de
- added previously removed frontend snes9express
* Tue May  4 2004 hmacht@suse.de
- updated to version 1.42
- added patch for not using the package's own zlib
- corrected filelist
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Tue May 27 2003 coolo@suse.de
- use BuildRoot
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Wed Jun  5 2002 ro@suse.de
- fix build on x86_64
* Fri Apr 19 2002 uli@suse.de
- link with g++
- ditched frontend, too much effort to fix for gcc 3.1
* Wed Dec  5 2001 uli@suse.de
- update -> 1.39 (mostly fixes for specific games)
* Mon Nov 12 2001 ro@suse.de
- no svgalib support
* Tue Mar 27 2001 uli@suse.de
- update -> 1.37c
- moved arch-dependent stuff from patches to spec
* Tue Feb 27 2001 uli@suse.de
- update -> 1.34a
* Tue Feb 20 2001 uli@suse.de
- no longer builds with XFree86 3.3.x
* Thu Nov  9 2000 uli@suse.de
- update -> 1.32
- snes9express update -> 1.26
* Sun Nov  5 2000 ro@suse.de
- fixed neededforbuild
* Thu Jul 27 2000 uli@suse.de
- statically linking libXxf86* from xf86 3 to ensure compatibility
* Fri Jul  7 2000 kukuk@suse.de
- fix for SPARC
* Wed Jun  7 2000 uli@suse.de
- moved docs to %%{_docdir}
* Wed Mar  1 2000 werner@suse.de
- Fix config.guess selection
* Wed Feb  9 2000 uli@suse.de
- update -> 1.29
* Wed Feb  2 2000 uli@suse.de
- defined __linux, __unix gcc 2.95 does not define by
  default
* Tue Feb  1 2000 uli@suse.de
- svga.cpp: removed inclusion of asm/io.h, still needs c++-safe
  sys/io.h
* Tue Feb  1 2000 uli@suse.de
- changed spec to work with config.guess returning ppc* instead of
  powerpc*
* Mon Oct 11 1999 uli@suse.de
- update -> 1.26
* Thu Sep 23 1999 uli@suse.de
- update -> 1.25
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Sep  9 1999 uli@suse.de
- fixed for PPC
* Tue Jul 13 1999 bs@suse.de
- use gtk and glib instead of gtkn and glibn
* Tue Jun 22 1999 uli@suse.de
- updated frontend -> 1.1
* Fri May  7 1999 uli@suse.de
- update 1.18e -> 1.19a
- still no go on AXP, svgalib might work
* Thu Mar 11 1999 uli@suse.de
- update 1.16a -> 1.18e
- fixed for glibc 2.1 and libc5
- AXP builds, but doesn't run yet
* Fri Jan  8 1999 uli@suse.de
- added gtk-based frontend snes9express version 0.99-3
* Mon Jan  4 1999 uli@suse.de
- new package, version 1.16a
